@@ -1,12 +1,12 @@
 package HTML::Strip::Whitespace;
-$HTML::Strip::Whitespace::VERSION = '0.2.2';
+$HTML::Strip::Whitespace::VERSION = '0.2.3';
 use strict;
 use warnings;
 
 use 5.016;
 
 package HTML::Strip::Whitespace::State;
-$HTML::Strip::Whitespace::State::VERSION = '0.2.2';
+$HTML::Strip::Whitespace::State::VERSION = '0.2.3';
 sub new
 {
     my $class = shift;
@@ -33,7 +33,7 @@ sub initialize
         HTML::TokeParser::Simple->new( to_array( $args{'parser_args'} ) );
 
     $self->{'strip_newlines'} = $args{'strip_newlines'} || 0;
-    $self->{'out_fh'} = $args{'out_fh'};
+    $self->{'out_fh'}         = $args{'out_fh'};
 
     # Get the first element to initialize the parser
     # Otherwise the first call to next_state would return undef;
@@ -47,11 +47,7 @@ sub next_state
     my $self = shift;
     ( $self->{'prev'}, $self->{'this'}, $self->{'next'} ) =
         ( $self->{'this'}, $self->{'next'}, $self->{'parser'}->get_token() );
-    if ( !defined( $self->{'this'} ) )
-    {
-        return undef;
-    }
-    return 1;
+    return defined( $self->{'this'} );
 }
 
 sub prev
@@ -97,7 +93,7 @@ sub is_preserving_start_tag
     {
         return $t->get_tag();
     }
-    return undef;
+    return '';
 }
 
 sub handle_text
@@ -180,7 +176,7 @@ sub process
 
 package HTML::Strip::Whitespace;
 
-use 5.008;
+use 5.016;
 use strict;
 use warnings;
 
@@ -193,7 +189,7 @@ use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS);
     'all' => [
         qw(
             html_strip_whitespace
-            )
+        )
     ]
 );
 
@@ -211,7 +207,7 @@ sub html_strip_whitespace
     my $source = $args{'source'}
         or die "source argument not specified.";
     my $strip_newlines = $args{'strip_newlines'} || 0;
-    my $out_fh = $args{'out'}
+    my $out_fh         = $args{'out'}
         or die "out argument not specified.";
     my $state = HTML::Strip::Whitespace::State->new(
         'parser_args'    => $source,
@@ -239,7 +235,7 @@ HTML.
 
 =head1 VERSION
 
-version 0.2.2
+version 0.2.3
 
 =head1 SYNOPSIS
 
@@ -357,14 +353,6 @@ L<https://metacpan.org/release/HTML-Strip-Whitespace>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Strip-Whitespace>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -373,14 +361,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Strip-Whitespace>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Strip-Whitespace>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -444,7 +424,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Shlomi Fish.
+This software is Copyright (c) 2024 by Shlomi Fish.
 
 This is free software, licensed under:
 
